Settings
========

*  ``JOYOUS_DEFAULT_EVENTS_VIEW``: Monthly, List or Weekly view		
*  ``JOYOUS_HOLIDAYS``: Observed holidays - e.g. NZ[WGN]		
*  ``JOYOUS_GROUP_SELECTABLE``: Enable group selection? False or True		
*  ``JOYOUS_GROUP_MODEL``: To swap out the group model		
*  ``JOYOUS_TIME_INPUT``: Prompt for 12 or 24 hour times
*  ``JOYOUS_EVENTS_PER_PAGE``: Page limit for a list of events
